@@ -28,13 +28,33 @@ if (!isGeneric("area")) {
 setMethod('area', signature(x='SpatialPolygons'), 
 	function(x, ...) {
 		if (couldBeLonLat(x)) {
-			warning('polygon area in square degrees is not very meaningful; use geosphere::areaPolygon for these polygons')
+
+			a <- 6378137
+			f <- 1/298.257223563
+			x <- x@polygons
+			n <- length(x)
+			res <- vector(length=n)
+			for (i in 1:n) {
+				parts <- length(x[[i]]@Polygons )
+				sumarea <- 0
+				for (j in 1:parts) {
+					crd <- x[[i]]@Polygons[[j]]@coords
+					ar <- .Call("polygonarea", as.double(crd[,1]), as.double(crd[,2]), as.double(a), as.double(f), PACKAGE='raster')
+					if (x[[i]]@Polygons[[j]]@hole) {
+						sumarea <- sumarea - ar
+					} else {
+						sumarea <- sumarea + ar
+					}
+				}
+				res[i] <- sumarea
+			}
+			return(res)
 		}
 		if (requireNamespace("rgeos")) {
 			rgeos::gArea(x, byid=TRUE)
 		} else {	
 			warning('install rgeos for better area estimation')
-			sapply(x@polygons, function(i) slot(i, 'area'))
+			sapply(x@polygons, function(i) methods::slot(i, 'area'))
 		}
 	}
 )	
@@ -43,8 +63,7 @@ setMethod('area', signature(x='SpatialPolygons'),
 setMethod('area', signature(x='RasterLayer'), 
 	function(x, filename='', na.rm=FALSE, weights=FALSE, ...) {
 
-		out <- raster(x)
-	
+		out <- raster(x)	
 		if (na.rm) {
 			if (! hasValues(x) ) {
 				na.rm <- FALSE
@@ -76,10 +95,11 @@ setMethod('area', signature(x='RasterLayer'),
 			out <- writeStart(out, filename=filename, ...)
 		}
 
-		dy <- pointDistance(c(0,0),c(0, yres(out) ), lonlat=TRUE)
+		dy <- .geodist(0, 0, 0, yres(out)) 
+
 		y <- yFromRow(out, 1:nrow(out))
-		#dx <- pointDistance(cbind(0, y), cbind(xres(out), y), lonlat=TRUE)
-		dx <- .haversine(0, y, xres(out), y)
+		dx <- .geodist(0, y, xres(out), y) 
+
 
 		tr <- blockSize(out)
 		pb <- pbCreate(tr$n, label='area', ...)
@@ -125,12 +145,12 @@ setMethod('area', signature(x='RasterLayer'),
 setMethod('area', signature(x='RasterStackBrick'), 
 	function(x, filename='', na.rm=FALSE, weights=FALSE, ...) {
 
+
 		if (! na.rm) {
 			return( area(raster(x), filename=filename, na.rm=FALSE, weights=weights, ...) )
 		}	
 		
 		out <- brick(x, values=FALSE)
-
 		if (! couldBeLonLat(out)) {
 			stop('This function is only useful for Raster* objects with a longitude/latitude coordinates')
 		}
@@ -160,8 +180,8 @@ setMethod('area', signature(x='RasterStackBrick'),
 			cl <- getCluster()
 			on.exit( returnCluster() )
 			nodes <- min(nrow(out), length(cl))	
-			cat( 'Using cluster with', nodes, 'nodes\n' )
-			flush.console()		
+			message( 'Using cluster with', nodes, 'nodes' )
+			utils::flush.console()		
 				
 			tr <- blockSize(out, minblocks=nodes)
 			pb <- pbCreate(tr$n, label='area', ...)
@@ -177,6 +197,7 @@ setMethod('area', signature(x='RasterStackBrick'),
 				vv[is.na(a)] <- NA
 				return(vv)
 			}
+			.sendCall <- eval( parse( text="parallel:::sendCall") )
 
 			parallel::clusterExport(cl, c('tr', 'dx', 'dy', 'out', 'nl'), envir=environment())
 			
