@@ -13,7 +13,7 @@ setMethod("atan2", signature(y='RasterLayer', x='RasterLayer'),
 	function(y, x) { 
 	
 		r <- raster(x)
-		compare(r, y)
+		compareRaster(r, y)
  
 		if (canProcessInMemory(r, 3)) {
 			r <- setValues(r, atan2(getValues(y), getValues(x)))
