@@ -10,12 +10,12 @@ setMethod('crop', signature(x='Spatial', y='ANY'),
 	
 		if (! inherits(y, 'SpatialPolygons')) {
 			if (inherits(y, 'Extent')) {
-				y <- methods::as(y, 'SpatialPolygons')
+				y <- as(y, 'SpatialPolygons')
 				y@proj4string <- x@proj4string
 			} else { 
 				y <- extent(y)
 				methods::validObject(y)
-				y <- methods::as(y, 'SpatialPolygons')
+				y <- as(y, 'SpatialPolygons')
 			}
 			y@proj4string <- x@proj4string		
 		}
