@@ -10,7 +10,7 @@
 		return(c(trim(s), NA)) 
 	} else {
 		first <- substr(s, 1, (pos-1))
-		second <- substr(s, (pos+1), nchar(s))
+		second <- substr(s, (pos+1), .nchar(s))
 		return(trim(c(first, second)))
 	}
 }
@@ -18,13 +18,13 @@
 
 .strSplitOnLastToken <- function(s, token="=") {
 	# not used here
-	pos <- unlist(strsplit(s, ''))
+	pos <- unlist(strsplit(s, ''), use.names = FALSE)
 	pos <- max(which(pos==token))
 	if (!is.finite(pos)) {
 		return(c(s, NA)) 
 	} else {
 		first <- substr(s, 1, (pos-1))
-		second <- substr(s, (pos+1), nchar(s))
+		second <- substr(s, (pos+1), .nchar(s))
 		return(trim(c(first, second)))
 	}
 }
