@@ -3,7 +3,7 @@
 # Version 0.9
 # Licence GPL v3
 
-.rasterFromIDRISIFile <- function(filename, crs=NULL, old=FALSE, ...) {
+.rasterFromIDRISIFile <- function(filename, crs=NA, old=FALSE, ...) {
 
 	if (old) {
 		idformat <- 'IDRISIold'
@@ -55,7 +55,7 @@
 	
 	x <- raster(ncols=nc, nrows=nr, xmn=xn, ymn=yn, xmx=xx, ymx=yx, crs=crs)
 
-	if (nchar(layernames) > 1) {
+	if (.nchar(layernames) > 1) {
 		# lnams <- unlist(strsplit(layernames, ':'))
 		lnams <- layernames
 	} else {
