@@ -34,6 +34,7 @@ function(x, size, exp=10, na.rm=TRUE, xy=FALSE, ext=NULL, sp=FALSE, ...) {
 		f <- cbind(as.integer(names(f)), f)
 	
 		ys <- list()
+		
 		for (i in 1:nrow(f)) {
 			if (is.na(f[i,1])) {
 				y <- v[is.na(v[, 2]),  ,drop=FALSE]
@@ -73,8 +74,8 @@ function(x, size, exp=10, na.rm=TRUE, xy=FALSE, ext=NULL, sp=FALSE, ...) {
 		sr <- sampleRandom(x, ss, na.rm=na.rm, ext=NULL, cells=TRUE, rowcol=FALSE, sp=FALSE)
 	
 		ys <- list()
-		for (i in f[,1]) {
-			y <- sr[sr[, 2] == i, ,drop=FALSE]
+		for (i in seq_len(nrow(f))) {
+			y <- sr[sr[, 2] == f[i,1], ,drop=FALSE]
 			if (nrow(y) == 0) {
 				warning("no samples found for value: ", i, ". Perhaps increase the value of 'ext'")
 			} else {
